@@ -344,7 +344,7 @@ my $complement;
 #
 #
 #
-       if  ($session{$ATTRLDAP}{$LDAPCONTROL}) { #the user have the good authorization 
+       if  (exists($session{$ATTRLDAP}{$LDAPCONTROL})) { #the user have the good authorization 
                                                # in order to access at application 
 	   $etat =1 ;# We open tge gate
            $complement =$session{$ATTRLDAP}{$LDAPCONTROL};
@@ -375,7 +375,7 @@ untie %session;
 
 ############################################
 $ligne_h = $dn;
-if ($complement) {
+if (defined($complement)) {
 $ligne_h.=":$complement";
 } 
 	    } ### end of search in cache 1 ,2 and 3
